@@ -5,24 +5,18 @@ import contextlib
 import json
 import queue
 import secrets
-import sys
 import threading
 import typing
 
-if sys.version_info < (3, 8):
-    from typing_extensions import Literal  # pragma: no cover
-else:
-    from typing import Literal  # pragma: no cover
-
 import httpcore
 import httpx
 import wsproto
-from httpcore.backends.base import AsyncNetworkStream, NetworkStream
+from httpcore import AsyncNetworkStream, NetworkStream
 from wsproto.connection import CloseReason
 
 from httpx_ws._ping import AsyncPingManager, PingManager
 
-JSONMode = Literal["text", "binary"]
+JSONMode = typing.Literal["text", "binary"]
 TaskFunction = typing.TypeVar("TaskFunction")
 TaskResult = typing.TypeVar("TaskResult")
 
